GetWeatherData_selection gets the weather data for the selected stations by downloading the data from the DWD ftp server
GetWeatherData_selection.RdGetWeatherData_selection gets the weather data for the selected stations by downloading the data from the DWD ftp server
Usage
GetWeatherData_selection(
stations_selected,
DWD_content,
repository = DWD_ftp_historical,
startdate = "1990-01-01"
)