Internal hook to optionally initialize the data directory when the user opts in via `options(weatherfunctions.auto_setup = TRUE)`.
dot-onLoad.RdInternal hook to optionally initialize the data directory when the user opts in via `options(weatherfunctions.auto_setup = TRUE)`.