makeplot3 a function to plot scenarios with smoothed variation ranges
makeplot3.Rdmakeplot3 a function to plot scenarios with smoothed variation ranges
Usage
makeplot3(
dfweather,
parameter,
BaseSize = 18,
ylabel = "",
xlabel = "Datum",
SelYear = 0,
IsLegend = TRUE
)