CreateScenarioWeather
CreateScenarioWeather.RdCreateScenarioWeather
Usage
CreateScenarioWeather(
df = NULL,
scenYear = 2024,
StartMonthSim = 9,
startYear = 2004,
ScenarioStartDay = NULL,
EndYear = 2024,
site_key = "L21"
)Arguments
- df
data frame with weather data
- scenYear
A year for which a scenario weather data is created
- StartMonthSim
A month for the start of the simulation scenario
- startYear
A year for the start of the simulation scenario
- ScenarioStartDay
A day for the start of the simulation scenario
- EndYear
A year for the end of the simulation scenario
- site_key
A key for the site