GetRainData_selection gets the rain data for the selected stations by downloading the data from the DWD ftp server
GetRainData_selection.RdGetRainData_selection gets the rain data for the selected stations by downloading the data from the DWD ftp server
Usage
GetRainData_selection(
stations_selected,
DWDRain_content,
repository = DWDRain_ftp_historical,
startdate = "1990-01-01"
)