InterpolateWeatherData interpolates the weather data from the selected station to the location
InterpolateWeatherData.RdInterpolateWeatherData interpolates the weather data from the selected station to the location
Usage
InterpolateWeatherData(
station_selected,
RainStation_selected = NULL,
weather_dat,
RainData = NULL,
maxError = 2,
startdate = "1990-01-01"
)